use strict; use warnings;
BEGIN {
  unless(eval q{ use 5.006; 1}) {
    print "Perl 5.006 or better required\n";
    exit;
  }
}

# This file was automatically generated by Dist::Zilla::Plugin::Alien v0.023.
use strict;
use warnings;

use Module::Build 0.28;
use lib qw{inc}; use My::ModuleBuild;

my %module_build_args = (
  "alien_bin_requires" => {
    "Alien::m4" => 0,
    "Alien::patch" => "0.06"
  },
  "alien_build_commands" => [
    "%{patch} -p1 < ../../patches/flex-2_5_39.diff",
    "%c --prefix=%s --disable-shared",
    "make"
  ],
  "alien_inline_auto_include" => [],
  "alien_install_commands" => [
    "make install"
  ],
  "alien_name" => "flex",
  "alien_repository" => {
    "exact_filename" => "flex-2.5.39.tar.gz",
    "host" => "sourceforge.net",
    "location" => "/projects/flex/files/",
    "protocol" => "http"
  },
  "configure_requires" => {
    "Alien::Base::ModuleBuild" => "0.020",
    "Capture::Tiny" => 0,
    "File::ShareDir" => "1.03",
    "File::chdir" => 0,
    "perl" => "5.006"
  },
  "dist_abstract" => "Find or build flex",
  "dist_author" => [
    "Graham Ollis <plicease\@cpan.org>"
  ],
  "dist_name" => "Alien-flex",
  "dist_version" => "0.08",
  "license" => "perl",
  "module_name" => "Alien::flex",
  "recursive_test_files" => 1,
  "requires" => {
    "Alien::Base" => "0.020",
    "File::ShareDir" => "1.03",
    "base" => 0,
    "perl" => "5.006"
  },
  "test_requires" => {
    "Test::More" => "0.94",
    "perl" => "5.006"
  }
);


my %fallback_build_requires = (
  "Test::More" => "0.94",
  "perl" => "5.006"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = My::ModuleBuild->new(%module_build_args);


$build->create_build_script;
